@@ -2,10 +2,10 @@ from typing import List, Optional, Tuple
 
 from fastapi import APIRouter, Depends, Query, Request, status
 from fastapi.responses import RedirectResponse
-from fastapi.security.oauth2 import OAuth2PasswordRequestForm
 from pydantic import AnyUrl
 
-from fief.apps.auth.templates import templates
+from fief.apps.auth.forms.auth import ConsentForm, LoginForm
+from fief.apps.auth.forms.base import FormHelper
 from fief.dependencies.auth import (
     check_unsupported_request_parameter,
     get_authorize_client,
@@ -16,7 +16,6 @@ from fief.dependencies.auth import (
     get_authorize_response_type,
     get_authorize_scope,
     get_authorize_screen,
-    get_consent_action,
     get_consent_prompt,
     get_login_session,
     get_needs_consent,
@@ -25,22 +24,20 @@ from fief.dependencies.auth import (
 )
 from fief.dependencies.authentication_flow import get_authentication_flow
 from fief.dependencies.current_workspace import get_current_workspace
-from fief.dependencies.locale import get_gettext, get_translations
 from fief.dependencies.session_token import get_session_token
 from fief.dependencies.tenant import get_current_tenant
 from fief.dependencies.users import UserManager, get_user_manager
 from fief.dependencies.workspace_repositories import get_session_token_repository
-from fief.exceptions import LoginException, LogoutException
-from fief.locale import Translations
-from fief.middlewares.csrf import check_csrf
+from fief.exceptions import LogoutException
+from fief.locale import gettext_lazy as _
 from fief.models import Client, LoginSession, Tenant, Workspace
 from fief.models.session_token import SessionToken
 from fief.repositories.session_token import SessionTokenRepository
-from fief.schemas.auth import LoginError, LogoutError
+from fief.schemas.auth import LogoutError
 from fief.services.authentication_flow import AuthenticationFlow
 from fief.settings import settings
 
-router = APIRouter(dependencies=[Depends(check_csrf), Depends(get_translations)])
+router = APIRouter()
 
 
 @router.get(
@@ -68,11 +65,11 @@ async def authorize(
     tenant = client.tenant
 
     if has_valid_session_token and prompt != "login":
-        redirection = tenant.url_path_for(request, "auth:consent.get")
+        redirection = tenant.url_path_for(request, "auth:consent")
     elif screen == "register":
-        redirection = tenant.url_path_for(request, "register:get")
+        redirection = tenant.url_path_for(request, "register:register")
     else:
-        redirection = tenant.url_path_for(request, "auth:login.get")
+        redirection = tenant.url_path_for(request, "auth:login")
 
     response = RedirectResponse(url=redirection, status_code=status.HTTP_302_FOUND)
     response = await authentication_flow.create_login_session(
@@ -90,56 +87,48 @@ async def authorize(
     return response
 
 
-@router.get("/login", name="auth:login.get")
-async def get_login(
+@router.api_route(
+    "/login",
+    methods=["GET", "POST"],
+    name="auth:login",
+    dependencies=[Depends(get_login_session)],
+)
+async def login(
     request: Request,
-    login_session: LoginSession = Depends(get_login_session),
-    translations: Translations = Depends(get_translations),
-):
-    return templates.LocaleTemplateResponse(
-        "login.html",
-        {"request": request, "tenant": login_session.client.tenant},
-        translations=translations,
-    )
-
-
-@router.post("/login", name="auth:login.post")
-async def post_login(
-    request: Request,
-    credentials: OAuth2PasswordRequestForm = Depends(OAuth2PasswordRequestForm),
-    login_session: LoginSession = Depends(get_login_session),
     user_manager: UserManager = Depends(get_user_manager),
     authentication_flow: AuthenticationFlow = Depends(get_authentication_flow),
     session_token: Optional[SessionToken] = Depends(get_session_token),
     tenant: Tenant = Depends(get_current_tenant),
-    _=Depends(get_gettext),
 ):
-    user = await user_manager.authenticate(credentials)
+    form_helper = FormHelper(
+        LoginForm,
+        "login.html",
+        request=request,
+        context={"tenant": tenant},
+    )
+    form = await form_helper.get_form()
 
-    if user is None or not user.is_active:
-        raise LoginException(
-            LoginError.get_bad_credentials(_("Invalid email or password")),
-            login_session.client.tenant,
+    if await form_helper.is_submitted_and_valid():
+        user = await user_manager.authenticate(form.get_credentials())
+        if user is None or not user.is_active:
+            return await form_helper.get_error_response(
+                _("Invalid email or password"), "bad_credentials"
+            )
+
+        response = RedirectResponse(
+            tenant.url_path_for(request, "auth:consent"),
+            status_code=status.HTTP_302_FOUND,
         )
-    # if requires_verification and not user.is_verified:
-    #     raise HTTPException(
-    #         status_code=status.HTTP_400_BAD_REQUEST,
-    #         detail=ErrorCode.LOGIN_USER_NOT_VERIFIED,
-    #     )
+        response = await authentication_flow.rotate_session_token(
+            response, user.id, session_token=session_token
+        )
+        return response
 
-    response = RedirectResponse(
-        tenant.url_path_for(request, "auth:consent.get"),
-        status_code=status.HTTP_302_FOUND,
-    )
-    response = await authentication_flow.rotate_session_token(
-        response, user.id, session_token=session_token
-    )
-
-    return response
+    return await form_helper.get_response()
 
 
-@router.get("/consent", name="auth:consent.get")
-async def get_consent(
+@router.api_route("/consent", methods=["GET", "POST"], name="auth:consent")
+async def consent(
     request: Request,
     login_session: LoginSession = Depends(get_login_session),
     session_token: Optional[SessionToken] = Depends(get_session_token),
@@ -148,11 +137,22 @@ async def get_consent(
     tenant: Tenant = Depends(get_current_tenant),
     workspace: Workspace = Depends(get_current_workspace),
     authentication_flow: AuthenticationFlow = Depends(get_authentication_flow),
-    translations: Translations = Depends(get_translations),
 ):
+    form_helper = FormHelper(
+        ConsentForm,
+        "consent.html",
+        request=request,
+        context={
+            "tenant": tenant,
+            "client": login_session.client,
+            "scopes": login_session.scope,
+        },
+    )
+    form = await form_helper.get_form()
+
     if session_token is None:
         return RedirectResponse(
-            tenant.url_path_for(request, "auth:login.get"),
+            tenant.url_path_for(request, "auth:login"),
             status_code=status.HTTP_302_FOUND,
         )
 
@@ -170,60 +170,39 @@ async def get_consent(
         )
         return response
 
-    return templates.LocaleTemplateResponse(
-        "consent.html",
-        {
-            "request": request,
-            "tenant": login_session.client.tenant,
-            "client": login_session.client,
-            "scopes": login_session.scope,
-        },
-        translations=translations,
-    )
+    if await form_helper.is_submitted_and_valid():
+        # Allow
+        if form.allow.data:
+            user_id = session_token.user_id
+            await authentication_flow.create_or_update_grant(
+                user_id, login_session.client, login_session.scope
+            )
+            response = (
+                await authentication_flow.get_authorization_code_success_redirect(
+                    login_session=login_session,
+                    authenticated_at=session_token.created_at,
+                    user=session_token.user,
+                    client=login_session.client,
+                    tenant=tenant,
+                    workspace=workspace,
+                )
+            )
+        # Deny
+        elif form.deny.data:
+            response = AuthenticationFlow.get_authorization_code_error_redirect(
+                login_session.redirect_uri,
+                login_session.response_mode,
+                "access_denied",
+                error_description=_("The user denied access to their data."),
+                state=login_session.state,
+            )
 
-
-@router.post("/consent", name="auth:consent.post")
-async def post_consent(
-    request: Request,
-    action: str = Depends(get_consent_action),
-    login_session: LoginSession = Depends(get_login_session),
-    session_token: Optional[SessionToken] = Depends(get_session_token),
-    tenant: Tenant = Depends(get_current_tenant),
-    workspace: Workspace = Depends(get_current_workspace),
-    authentication_flow: AuthenticationFlow = Depends(get_authentication_flow),
-    _=Depends(get_gettext),
-):
-    if session_token is None:
-        return RedirectResponse(
-            tenant.url_path_for(request, "auth:login.get"),
-            status_code=status.HTTP_302_FOUND,
+        response = await authentication_flow.delete_login_session(
+            response, login_session
         )
+        return response
 
-    if action == "allow":
-        user_id = session_token.user_id
-        await authentication_flow.create_or_update_grant(
-            user_id, login_session.client, login_session.scope
-        )
-        response = await authentication_flow.get_authorization_code_success_redirect(
-            login_session=login_session,
-            authenticated_at=session_token.created_at,
-            user=session_token.user,
-            client=login_session.client,
-            tenant=tenant,
-            workspace=workspace,
-        )
-    elif action == "deny":
-        response = AuthenticationFlow.get_authorization_code_error_redirect(
-            login_session.redirect_uri,
-            login_session.response_mode,
-            "access_denied",
-            error_description=_("The user denied access to their data."),
-            state=login_session.state,
-        )
-
-    response = await authentication_flow.delete_login_session(response, login_session)
-
-    return response
+    return await form_helper.get_response()
 
 
 @router.get("/logout", name="auth:logout")
@@ -234,7 +213,6 @@ async def logout(
         get_session_token_repository
     ),
     tenant: Tenant = Depends(get_current_tenant),
-    _=Depends(get_gettext),
 ):
     if redirect_uri is None:
         raise LogoutException(
