@@ -4,9 +4,9 @@ from fastapi import Depends, HTTPException, status
 from fastapi.security import APIKeyCookie
 
 from fief.crypto.token import get_token_hash
-from fief.dependencies.main_managers import get_admin_session_token_manager
-from fief.managers import AdminSessionTokenManager
+from fief.dependencies.main_repositories import get_admin_session_token_repository
 from fief.models import AdminSessionToken
+from fief.repositories import AdminSessionTokenRepository
 from fief.settings import settings
 
 cookie_scheme = APIKeyCookie(
@@ -16,12 +16,14 @@ cookie_scheme = APIKeyCookie(
 
 async def get_optional_admin_session_token(
     token: Optional[str] = Depends(cookie_scheme),
-    manager: AdminSessionTokenManager = Depends(get_admin_session_token_manager),
+    repository: AdminSessionTokenRepository = Depends(
+        get_admin_session_token_repository
+    ),
 ) -> Optional[AdminSessionToken]:
     if token is None:
         return None
     token_hash = get_token_hash(token)
-    session_token = await manager.get_by_token(token_hash)
+    session_token = await repository.get_by_token(token_hash)
     return session_token
 
 
