@@ -8,12 +8,20 @@ from sqlalchemy.sql.sqltypes import JSON, String
 
 from fief.models.base import WorkspaceBase
 from fief.models.client import Client
-from fief.models.generics import GUID, CreatedUpdatedAt, TIMESTAMPAware, UUIDModel
+from fief.models.generics import (
+    GUID,
+    CreatedUpdatedAt,
+    ExpiresAt,
+    TIMESTAMPAware,
+    UUIDModel,
+)
 from fief.models.user import User
+from fief.settings import settings
 
 
-class AuthorizationCode(UUIDModel, CreatedUpdatedAt, WorkspaceBase):
+class AuthorizationCode(UUIDModel, CreatedUpdatedAt, ExpiresAt, WorkspaceBase):
     __tablename__ = "authorization_codes"
+    __lifetime_seconds__ = settings.authorization_code_lifetime_seconds
 
     code: str = Column(
         String(length=255),
