@@ -8,11 +8,13 @@ from sqlalchemy.sql.sqltypes import JSON, String
 
 from fief.models.base import WorkspaceBase
 from fief.models.client import Client
-from fief.models.generics import GUID, CreatedUpdatedAt, UUIDModel
+from fief.models.generics import GUID, CreatedUpdatedAt, ExpiresAt, UUIDModel
+from fief.settings import settings
 
 
-class LoginSession(UUIDModel, CreatedUpdatedAt, WorkspaceBase):
+class LoginSession(UUIDModel, CreatedUpdatedAt, ExpiresAt, WorkspaceBase):
     __tablename__ = "login_sessions"
+    __lifetime_seconds__ = settings.login_session_lifetime_seconds
 
     token: str = Column(
         String(length=255),
