@@ -1,16 +1,16 @@
-from datetime import datetime
-
 from pydantic import UUID4
 from sqlalchemy import Column, ForeignKey, String
 from sqlalchemy.orm import relationship
 
 from fief.models.base import WorkspaceBase
-from fief.models.generics import GUID, CreatedUpdatedAt, TIMESTAMPAware, UUIDModel
+from fief.models.generics import GUID, CreatedUpdatedAt, ExpiresAt, UUIDModel
 from fief.models.user import User
+from fief.settings import settings
 
 
-class SessionToken(UUIDModel, CreatedUpdatedAt, WorkspaceBase):
+class SessionToken(UUIDModel, CreatedUpdatedAt, ExpiresAt, WorkspaceBase):
     __tablename__ = "session_tokens"
+    __lifetime_seconds__ = settings.session_lifetime_seconds
 
     token: str = Column(
         String(length=255),
@@ -18,9 +18,6 @@ class SessionToken(UUIDModel, CreatedUpdatedAt, WorkspaceBase):
         index=True,
         unique=True,
     )
-    expires_at: datetime = Column(
-        TIMESTAMPAware(timezone=True), nullable=False, index=True
-    )
 
     user_id: UUID4 = Column(GUID, ForeignKey(User.id, ondelete="CASCADE"), nullable=False)  # type: ignore
     user: User = relationship("User", lazy="joined")
