@@ -1,4 +1,5 @@
 from fief.tasks.base import SendTask, send_task
+from fief.tasks.cleanup import cleanup
 from fief.tasks.forgot_password import on_after_forgot_password
 from fief.tasks.register import on_after_register
 from fief.tasks.roles import on_role_updated
@@ -7,6 +8,7 @@ from fief.tasks.user_permissions import on_user_role_created, on_user_role_delet
 __all__ = [
     "send_task",
     "SendTask",
+    "cleanup",
     "on_after_forgot_password",
     "on_after_register",
     "on_role_updated",
